
/****************************************************************************
** Form implementation generated from reading ui file './search.ui'
**
** Created: Fri Jan 12 20:07:26 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "search.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qframe.h>
#include <qheader.h>
#include <qlistview.h>
#include <qcombobox.h>
#include <qradiobutton.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const char* const img0_search[] = { 
"11 23 26 1",
"w c #0075e6",
"x c #0075ee",
"c c #0879ee",
"s c #1081ee",
"v c #2989ee",
"b c #3991ee",
"a c #62aaf6",
"l c #6ab2f6",
"o c #73b2f6",
"j c #7bb6ff",
"q c #8bbeff",
"t c #a4cef6",
"d c #a4ceff",
"e c #acceff",
"r c #acd2ff",
"# c #b4d6ff",
"m c #cddeff",
"p c #deeaff",
"k c #deeeff",
"f c #e6eeff",
"u c #eeeeff",
"h c #eef2ff",
"n c #f6f2ff",
"g c #f6f6ff",
"i c #fffaff",
". c #ffffff",
".......#abc",
".....dcefgh",
"...ijaggggg",
"..klmgnghgn",
"..opggggggg",
".qrgnghgngh",
".sggggggggg",
"t#nghgnghgn",
"auggggggggg",
"vghgnghgngh",
"sgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg"};

static const char* const img1_search[] = { 
"24 23 5 1",
"# c #0075ee",
". c #0879ee",
"c c #eef2ff",
"a c #f6f2ff",
"b c #f6f6ff",
".#.#.#.#.#.#.#.#.#.#.#.#",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb"};

static const char* const img2_search[] = { 
"11 23 26 1",
"x c #0075e6",
"w c #0075ee",
". c #0879ee",
"v c #087dee",
"s c #1081ee",
"u c #2089ee",
"# c #3991ee",
"a c #62aaf6",
"m c #6ab2f6",
"p c #73b2ff",
"i c #7bb6ff",
"r c #94c6ff",
"h c #a4ceff",
"g c #acceff",
"q c #acd2ff",
"b c #b4d6ff",
"l c #cddeff",
"o c #deeaff",
"n c #deeeff",
"f c #e6eeff",
"t c #eeeeff",
"k c #eef2ff",
"d c #f6f2ff",
"e c #f6f6ff",
"j c #fffaff",
"c c #ffffff",
".#abccccccc",
"defg.hccccc",
"eeeeeaijccc",
"kedekelmncc",
"eeeeeeeopcc",
"dekedekeqrc",
"eeeeeeeeesc",
"kedekedekbh",
"eeeeeeeeeta",
"dekedekedeu",
"eeeeeeeeeev",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee.",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee.",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee."};

static const char* const img3_search[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img4_search[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img5_search[] = { 
"123 21 35 1",
"# c #004894",
"a c #004c94",
". c #004c9c",
"y c #00509c",
"u c #084c9c",
"f c #08509c",
"E c #0850a4",
"h c #0855a4",
"r c #0859a4",
"F c #1059a4",
"v c #1059ac",
"w c #105dac",
"b c #1061ac",
"j c #1061b4",
"B c #1065b4",
"s c #1861b4",
"n c #1865b4",
"g c #1869b4",
"o c #1869bd",
"e c #186dbd",
"D c #186dc5",
"p c #2069bd",
"z c #206dbd",
"q c #206dc5",
"m c #2071c5",
"A c #2075c5",
"t c #2075cd",
"G c #2079cd",
"x c #2975cd",
"i c #2979cd",
"C c #2979d5",
"d c #297dcd",
"c c #297dd5",
"k c #2981d5",
"l c #3181d5",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"#################################################################################################################a#########",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###########################################################################################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"#######bccdcccef##gcg##############################################hecdib#############################################gcg##",
"a#.#a#.jkclckclma#icn#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#nckclcko.#a#.#a#.#a#.#a#.#a#..oj.#a#.#a#.#ajp#a#noa#icn#.",
"#######qdj###rcca################################################rcce.#sdcf####################idr##########gcb##ocs#######",
".#a#.#atlra#.fki.rkcu#uolciv.#uolckj.#jcpjkt.wtclea#.jcclmu#.#a#.mke.#a#xcn#.nkcloa#.mkjmckj.rkclcjapckco#ailckocckcprkcu#a",
"#######icf##ymdz#sdi#fAcccdcfumcccdcb#bcicdjBcdccce#Bcdccce#####ycdh########mcdccce##idcccdcysdcccyAccdccsfcccdjccdcwsdi###",
"a#.#a#hckclckcxfaoleaelmf#xcnnlmu#qcq#qccw.hkcn#jcc#a#.#jcx#a#.#wci#a#.#a#.jkiw#wclhfclmualcf#nco#.#a#.okn.rkt.#vci#aolea#.",
"######wcdcccdb###Acs#icw#####iccdcccg#tcb##sdA######fnBCdcg#####rcm########tdn###icwhciu#rcC##Dcw##bBoccdb#sdo##bcg##Acs###",
".#a#.#nco#umlma#.ikvhcka.#a#.ikv.#a#.#ccE#aelna#.#avlmj#icj#.#a#vcc#.#anlnailva#hckhncm#.jkm.#cch#ocmhfclfamlja#mcn#.ikv.#a",
"######ecwa#hccr#fcdfycdr#qdi#idz#wdiaFdi###ocm#hicwocn#jccy######Cdo##bccw#mcq#.Dcm#gcB##odo#hdi##Acr#ect##icF##ich#fcdf###",
"a#.#a#icv#.#qcq#jcc#amlckclrawlckcljawlea#.rkclckm.jkclcki.#a#.#ajlckclco#.wkclckih#tcs#amlwavlckrmckclcm#uckcn.kcljjcc#a#.",
"######ica###fccfBcD##.ecdAr###widib##ncn####wiccg##ueccndi########bidcDb####wicceh##Gcf##ich#.mcdffidigce##qdcw#eccbBcD####",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#.#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###########################################################################################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###########################################################################################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a"};

static const char* const img6_search[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img7_search[] = { 
"11 18 53 1",
"g c #0075e6",
"b c #0075ee",
"R c #0079e6",
"Y c #0079ee",
". c #0879ee",
"t c #1881ee",
"x c #2989ee",
"S c #298dee",
"X c #3191ee",
"U c #3991ee",
"L c #5aa5f6",
"C c #62aaf6",
"# c #73aae6",
"d c #73aee6",
"a c #73aeee",
"e c #7baee6",
"c c #7bb2ee",
"O c #7bb6ff",
"f c #83b6ee",
"P c #83baff",
"h c #8bbaee",
"i c #8bbeee",
"Q c #8bbeff",
"l c #94beee",
"j c #94c2ee",
"N c #94c6ff",
"k c #9cc2f6",
"n c #9cc6ee",
"m c #a4c6f6",
"q c #a4caf6",
"G c #a4cef6",
"p c #accaf6",
"o c #accef6",
"W c #acd2f6",
"M c #acd2ff",
"s c #b4d2f6",
"V c #b4d6ff",
"r c #bddaf6",
"y c #bddaff",
"w c #c5daf6",
"v c #c5deff",
"u c #cde2ff",
"z c #d5e6f6",
"B c #d5e6ff",
"A c #deeaff",
"T c #deeeff",
"H c #e6f2ff",
"E c #eef2ff",
"F c #eef6ff",
"D c #f6f6ff",
"J c #f6faff",
"K c #fffaff",
"I c #ffffff",
".#a#a#a#a#a",
"bcdcecdcdcd",
".ffffffffff",
"ghhhhhhihhh",
".jklkjkjkjk",
"bmnmnmnmnmn",
".oopopoooqo",
"grsssssssss",
"tuvwvwvwvwv",
"xyzABAzABAz",
"CCDEFEDEFEF",
"G.HIJIJIJIK",
"IxLIIIIIIII",
"IMgNIIIIIII",
"IIO.PIIIIII",
"IIIQRSuIJJF",
"IIIITU.LVBI",
"IIIIIIWLXYg"};

static const char* const img8_search[] = { 
"21 18 33 1",
"E c #0075e6",
"C c #0075ee",
"D c #0079ee",
"# c #73aae6",
"c c #73aee6",
". c #73aeee",
"a c #7baee6",
"b c #7bb2ee",
"d c #83b6ee",
"e c #8bbaee",
"f c #8bbeee",
"j c #94beee",
"h c #94c2ee",
"i c #94c2f6",
"g c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"o c #accaf6",
"n c #accef6",
"q c #acd2f6",
"p c #b4d2f6",
"s c #c5daf6",
"r c #c5deff",
"v c #d5e6f6",
"t c #d5e6ff",
"u c #deeaff",
"x c #eef2ff",
"w c #eef6ff",
"y c #f6f6ff",
"z c #f6faff",
"B c #fffaff",
"A c #ffffff",
".#.#.#.#.#.#.#.#.#.#.",
"abcbcbcbabcbabcbcbcbc",
"ddddddddddddddddddddd",
"eeeeeeefefeeeeeeeeeee",
"ghghghghghijghghgjghg",
"klklklklklklklkmklkmk",
"nonnnnnonnnonnnnnnnon",
"ppppppppppppqpppppppp",
"rsrsrsrsrsrsrsrsrsrsr",
"tuvutuvutuvutututuvut",
"wxyxwxwxwxyxwxwxwxwxw",
"zABAzBzAzAzAzBzAzAzAz",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAABABAAAAABAAAAA",
"wywywywywywywywywywyw",
"AAAAAAAAAAAAAAAAAAAAA",
"CDEDCDEDCDEDCDEDCDEDC"};

static const char* const img9_search[] = { 
"11 18 51 1",
"d c #0075e6",
"g c #0075ee",
"M c #0079ee",
"a c #0879ee",
"T c #087dee",
"u c #107dee",
"K c #2085ee",
"z c #2089ee",
"R c #3191ee",
"V c #52a1f6",
"E c #5aa5f6",
"J c #62aaf6",
"D c #62aef6",
"# c #73aae6",
"b c #73aee6",
". c #73aeee",
"P c #73b6f6",
"c c #7bb2ee",
"e c #83b6ee",
"O c #83beff",
"f c #8bbaee",
"j c #94beee",
"i c #94c2ee",
"L c #94c6ff",
"h c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"I c #a4caf6",
"N c #a4ceff",
"o c #accaf6",
"n c #accef6",
"W c #acceff",
"p c #b4d2f6",
"S c #b4d6ff",
"q c #bddaf6",
"y c #bddaff",
"s c #c5daf6",
"r c #c5deff",
"t c #cde2ff",
"Q c #cde6ff",
"x c #d5e6f6",
"v c #d5e6ff",
"U c #d5eaff",
"w c #deeaff",
"B c #eef2ff",
"A c #eef6ff",
"C c #f6f6ff",
"F c #f6faff",
"H c #fffaff",
"G c #ffffff",
".#.#.#.#.#a",
"bcbcbcbcbcd",
"eeeeeeeeeea",
"ffffffffffg",
"hihihjhihja",
"klklklkmkld",
"nnnnnononna",
"pppppppppqg",
"rsrsrsrsrtu",
"vwvwvwxwvyz",
"ABABABABCDE",
"FGFHFGFGBuI",
"GGGGGGGGJKG",
"GGGGGGGLMNG",
"GGGGGGOaPGG",
"AFFGQRMOHGG",
"GvSETRUGGGG",
"gMRVWGGGGGG"};

static const char* const img10_search[] = { 
"34 31 4 1",
"a c #004894",
"b c #004c94",
"# c #004c9c",
". c #ffffff",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba"};

static const char* const img11_search[] = { 
"51 16 89 2",
".R c #000000",
"#w c #000400",
"#. c #000810",
".o c #000c10",
".M c #000c18",
".n c #001020",
".m c #001429",
".l c #001831",
".p c #001c39",
".k c #002041",
".j c #00244a",
".g c #002c5a",
".i c #003062",
".f c #00346a",
".e c #00386a",
".d c #003873",
".9 c #003c73",
".c c #003c7b",
".h c #004083",
".b c #00448b",
".# c #004894",
".a c #004c94",
"Qt c #004c9c",
".5 c #080808",
".0 c #080c10",
".V c #080c18",
".G c #081018",
"#t c #101010",
"#l c #101410",
".z c #101820",
"#n c #181418",
"#h c #181818",
".U c #181c18",
".q c #182431",
".Z c #201c20",
"#c c #202020",
"#v c #202420",
".8 c #292429",
".3 c #312c31",
".L c #313031",
"#u c #313431",
".Y c #393839",
".4 c #393c39",
"#k c #413c41",
".N c #414041",
".F c #4a444a",
"#g c #4a484a",
"#b c #4a4c4a",
".T c #524c52",
".7 c #5a595a",
"#s c #625d62",
".r c #626162",
".2 c #626562",
".A c #62656a",
".K c #6a656a",
".y c #6a696a",
".W c #6a6d73",
".X c #7b757b",
"#i c #7b797b",
"#f c #837d83",
".E c #838183",
".S c #838583",
"#a c #8b858b",
".s c #8b898b",
"#r c #8b8d8b",
".6 c #948d94",
"#d c #949194",
".x c #9c999c",
"#p c #9c9d9c",
".J c #a49da4",
".t c #a4a1a4",
".B c #aca5ac",
"## c #acaaac",
".D c #acaeac",
"#o c #b4aeb4",
".O c #b4b2b4",
".1 c #b4b6b4",
"#e c #bdb6bd",
".I c #bdbabd",
".H c #bdbebd",
".w c #c5bec5",
".P c #c5c2c5",
".Q c #c5c6c5",
".C c #cdc6cd",
".u c #cdcacd",
".v c #d5ced5",
"#j c #d5d2d5",
"#m c #eee6ee",
"#q c #eeeaee",
"Qt.#.a.#Qt.#.a.#Qt.#.a.#.#.b.b.c.c.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.f.g",
".#.#.#.#.#.#.#.#.#.#.b.h.d.i.j.k.l.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.n.o",
".a.#Qt.#.a.#Qt.#.#.c.f.j.p.n.q.r.s.t.u.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.w.x.y",
".#.#.#.#.#.#.b.h.i.j.n.z.A.B.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.C.D.E.F",
"Qt.#.a.#.#.b.c.j.m.G.A.H.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.I.J.K.L",
".#.#.#.#.h.f.p.M.N.O.P.Q.P.C.P.Q.R.R.R.R.R.C.P.Q.P.C.P.Q.P.C.P.Q.P.C.R.R.P.C.P.Q.P.C.P.Q.P.C.P.O.S.T.U",
".a.#.#.h.g.m.V.W.P.P.P.P.P.P.P.P.R.R.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.w.t.X.Y.Z",
".#.#.h.g.n.0.S.P.H.P.H.P.H.P.H.P.R.R.H.P.H.P.H.P.R.R.R.P.H.R.R.R.H.P.R.R.H.P.H.P.H.P.H.P.H.P.1.x.2.3.4",
"Qt.b.f.m.5.E.w.H.w.H.w.H.w.H.w.H.R.R.R.R.R.H.w.R.R.H.w.H.R.R.w.H.w.H.R.R.w.H.w.H.w.H.w.H.w.H.O.6.7.8.y",
".b.9.p#..y.I.I.I.I.I.I.I.I.I.I.I.R.R.I.I.I.I.I.I.R.R.I.I.R.R.I.I.I.I.R.R.I.I.I.I.I.I.I.I.I.I###a#b#c#d",
".h.j.n.N.I#e.I#e.I#e.I#e.I#e.I#e.R.R.I#e.I#e.I#e.I.R.R#e.R.R.I#e.I#e.R.R.I#e.I#e.I#e.I#e.I#e.B#f#g#h.I",
".i.m.0##.O.1.O#e.O.1.O#e.O.1.O#e.R.R.R.R.R.1.O.R.R.R.O#e.O.R.R.R.O.1.R.R.O.1.O#e.O.1.O#e.O.1.t#i.4#h#j",
".j#..y.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.t#i#k#l#m",
".n#n##.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O#p.X.Y#n#q",
".L#b.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.E#s.L#t.P",
"#u#v.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z#h#n.5#w.2"};

static const char* const img12_search[] = { 
"28 31 202 2",
"ao c #000008",
"#k c #000810",
"#d c #000c18",
"af c #001018",
"#j c #001020",
"#c c #001429",
"#S c #001831",
"#5 c #001c39",
"#i c #002041",
"#b c #00244a",
"#I c #002852",
"#h c #002c5a",
"#a c #003062",
"#4 c #003462",
"#y c #00346a",
"#H c #003873",
"#g c #003c7b",
"## c #004083",
"#x c #004483",
"#. c #00448b",
"#p c #00488b",
".9 c #004894",
"#o c #004c94",
".8 c #004c9c",
"#q c #080810",
"aE c #101820",
"aw c #102439",
"#6 c #182020",
".N c #202020",
".H c #202420",
"ax c #202429",
".G c #292829",
".7 c #292c29",
".V c #312c31",
".F c #313031",
".2 c #313431",
".E c #393439",
".1 c #393839",
".M c #393c39",
"#T c #393c41",
".D c #414041",
".O c #414441",
"#l c #41444a",
"aj c #4195ee",
".C c #4a444a",
".W c #4a4c4a",
"aB c #4a99ee",
"ap c #525052",
".6 c #525552",
"#J c #52555a",
"#8 c #52a1ee",
".B c #5a555a",
".0 c #5a595a",
".L c #5a5d5a",
".w c #626162",
".v c #626562",
"a7 c #62797b",
"bh c #6a656a",
".x c #6a696a",
".u c #6a6d6a",
"#F c #6a9dc5",
"al c #6aaeee",
".t c #737173",
"bc c #738d94",
"a4 c #73aed5",
"a# c #73b2f6",
".K c #7b797b",
".3 c #7b7d7b",
".Z c #7b7d83",
"b# c #7b999c",
"#B c #7ba1c5",
"aG c #7baad5",
"aQ c #7bb2d5",
"a. c #7bb6ee",
".s c #837d83",
".5 c #838183",
".r c #83858b",
"bf c #839594",
"#7 c #83a5cd",
"#E c #83aad5",
"#L c #83b2d5",
"#U c #83b6cd",
"#Y c #83bef6",
".A c #8b858b",
".P c #8b898b",
"ag c #8b8d8b",
"a1 c #8baab4",
"#Q c #8bb6de",
"ar c #8bbad5",
"ay c #8bbed5",
"#2 c #8bbede",
"ad c #8bc2d5",
"#X c #8bc2f6",
"an c #8bc6de",
"aZ c #8bc6e6",
"a6 c #949194",
".q c #94959c",
"#D c #94b6d5",
"bd c #94bec5",
"#u c #94bed5",
"az c #94bee6",
"#A c #94c2d5",
"aS c #94c2de",
"#R c #94c6de",
"aX c #94cae6",
"aY c #94cee6",
".4 c #9c959c",
".J c #9c9da4",
"b. c #9caaac",
"#C c #9cb6d5",
"#G c #9cc6de",
"aT c #9cc6e6",
"a2 c #9ccacd",
"#v c #9ccade",
"aL c #9cceee",
"aD c #9cd2e6",
"aK c #9cd6e6",
"#e c #a49da4",
".p c #a4a1a4",
"ah c #a4bede",
"as c #a4cae6",
"#9 c #a4caf6",
".Y c #acaaac",
"a8 c #accecd",
"aW c #acdae6",
".j c #b4b2b4",
".Q c #b4b6b4",
".k c #b4b6bd",
"#3 c #b4dae6",
"a0 c #b4daee",
"aU c #b4deff",
".i c #bdb6bd",
".h c #bdbabd",
".I c #bdbebd",
"be c #bddede",
"a9 c #bddee6",
"aF c #bddeee",
"aJ c #bddef6",
"ac c #bde6ff",
"#m c #c5bec5",
".g c #c5c2c5",
".f c #c5c6c5",
"#V c #c5cee6",
"#M c #c5d2e6",
"bg c #c5dede",
"aO c #c5def6",
"#t c #c5e2ee",
"aR c #c5e6e6",
"bb c #c5e6ee",
"a3 c #c5eaee",
"a5 c #c5eaff",
"#P c #c5eeff",
".R c #cdc6cd",
".o c #cdcacd",
".S c #cdcecd",
"#w c #cde6ee",
"#K c #cdeaee",
"am c #cdeeff",
"#1 c #cdf6ff",
".e c #d5ced5",
"#r c #d5d2d5",
".d c #d5d6d5",
"ak c #d5e6f6",
"#z c #d5eaee",
"ai c #d5eaff",
"aP c #d5eef6",
"aC c #d5eeff",
"aM c #d5faff",
".z c #dedade",
".U c #dedede",
".n c #dedee6",
"#s c #deeaee",
"av c #deeeee",
"#0 c #def6f6",
"#O c #defaff",
".c c #e6dee6",
"aq c #e6e2e6",
"#f c #e6e6e6",
"#n c #e6eaee",
"ba c #e6eeee",
"ae c #e6eef6",
"#Z c #e6f2f6",
"au c #e6f6ff",
"aH c #e6faf6",
"ab c #e6faff",
".X c #eee6ee",
".b c #eeeaee",
".m c #eeeeee",
"aV c #eeeef6",
"#W c #eef2ff",
"aI c #eef6ff",
"aN c #eefaff",
"at c #eeffff",
".y c #f6eef6",
".T c #f6f2f6",
".a c #f6f6ff",
"aA c #f6faf6",
"#N c #f6ffff",
".l c #fff6ff",
".# c #fffaff",
"aa c #fffff6",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.i.k",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.l.m.n.o.i.p.q.r.s.t.u.v.v.w.x",
"QtQtQtQtQtQtQtQtQtQtQt.l.y.z.g.p.A.x.B.C.D.E.F.G.G.H.G.G",
"QtQtQtQtQtQtQtQtQt.#.b.z.I.J.K.L.M.G.N.G.O.u.P.p.Q.R.S.o",
"QtQtQtQtQtQtQt.#.T.U.f.J.s.B.M.N.V.W.P.h.X.b.m.b.y.b.m.b",
"QtQtQtQtQtQt.a.b.S.Y.Z.0.1.N.2.3.h.b.b.b.b.b.b.b.b.b.b.b",
"QtQtQtQtQt.l.X.g.4.v.D.N.E.5.e.b.m.b.y.b.m.b.y.b.m.b.y.b",
"QtQtQtQt.T.c.i.P.6.7.N.x.f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".8.9.9#.###a#b#c#d.G#e#f.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".9.9#.#g#h#i#j#k#l#m.b.b.b.b#n#n#n#n#n.b.b.b.b.b.b.b.b.b",
"#o#p###a#i#j#q.0#r.b.y.b.m#s#t#u#u#v#w#n.m.b.y.b.m.b.y.b",
"#.#x#y#b#j#k.L.z.b.b.b.b#z#A#B#C#D#E#F#G#z.b.b.b.b.b.b.b",
"#.#H#I#c#k#J.U.b.y.b.m#K#L#MQtQt#N#O#P#Q#R#s.m.b.y.b.m.b",
"#H#h#S#d#T.e.b.b.b.b#s#U#V#W#X#Y#ZQt#0#1#2#3#n.b.b.b.b.b",
"#4#5#j#6.i.b.y.b.m#n#t#7Qt#8#9a.a#aaQtabacadae.b.m.b.y.b",
"#5af#qag.b.b.b.b.b#n#AahaiajaaakalQtaa#Naman#z.b.b.b.b.b",
"#kaoapaq.y.b.m.b.y#narasata.Qtaka#aaQt#Nau#Rav.b.y.b.m.b",
"awax.Q.b.b.b.b.b.b#nayaz#OQtaaaAaB#WaaQtaCaD#s.b.b.b.b.b",
"aE.x.b.b.m.b.y.b.m#naFaG#1aHQtaaak#8aIQtaJaKae.b.m.b.y.b",
"ax#m.b.b.b.b.b.b.b.b#sayaLaMaNQtaaaOaaQtaPaQaR.b.b.b.b.b",
".waq.m.b.y.b.m.b.y.b.m#zaSaTamab#NaNQtaaabaUay#zaV.b.m.b",
".p.b.b.b.b.b.b.b.b.b.b.b#zaWanaXaYaZa0#OaN#Na1a2#s.b.b.b",
"#r.b.y.b.m.b.y.b.m.b.y.b.m#nae#zava3a4a5Qtaqa6a7a8#n.y.b",
"#f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#na9aQb..g.o.5b##s.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bbabbbc.5.R.pbd#s.m.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#nbeb#bfbgaR#n.b.b",
".m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bba#z#w#zba.b.y.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m",
".xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh"};

static const char* const img13_search[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img14_search[] = { 
"57 17 94 2",
".k c #181c18",
".c c #202020",
".B c #202420",
".A c #292429",
".y c #292829",
".4 c #312c31",
"## c #313031",
"#. c #313431",
".5 c #393431",
".9 c #393439",
"#i c #393839",
".K c #393c39",
".E c #3991ee",
".u c #3995ee",
".U c #413c41",
".Z c #414041",
".P c #414441",
".D c #4195ee",
".t c #4195f6",
".l c #4a444a",
"#A c #4a484a",
".s c #4a4c4a",
".d c #524c52",
".R c #525052",
".C c #525552",
"#B c #5a555a",
".L c #5a595a",
".S c #5a5d5a",
".b c #625d62",
".X c #626562",
"#y c #629152",
".7 c #6a656a",
".J c #6a696a",
".j c #6a6d6a",
".0 c #6a6d73",
"#k c #6aaa6a",
"#u c #6ac64a",
".I c #736d73",
"#c c #737173",
".Y c #737573",
"#w c #73aa39",
"#m c #7b717b",
"#f c #7b757b",
".z c #7b797b",
".Q c #7b7d7b",
"#x c #7baa41",
"#p c #7bc27b",
".g c #838183",
".q c #838583",
"#s c #83ce4a",
".6 c #8b858b",
".a c #8b898b",
".v c #8b8d8b",
".F c #949194",
".o c #949594",
"#o c #94c68b",
".T c #9c9594",
".H c #9c999c",
"#v c #9cb294",
"#h c #a49da4",
".x c #a4a1a4",
".O c #a4a5a4",
".r c #aca5ac",
".3 c #acaaac",
"#r c #acb6ac",
".8 c #b4aeb4",
"#j c #b4beb4",
".2 c #bdbabd",
"#n c #bdc2bd",
"#l c #bdc6bd",
"#t c #bdff62",
"#e c #c5bec5",
".h c #c5c2c5",
".1 c #c5c6c5",
".W c #cdcacd",
"#q c #d5ced5",
".p c #d5d2d5",
".i c #d5d6d5",
"#z c #dedad5",
".m c #dedade",
".e c #dedede",
"#g c #dee2de",
".n c #e6dee6",
".f c #e6e2e6",
".M c #e6e6e6",
"#b c #eee6ee",
".# c #eeeaee",
".V c #eeeeee",
"#d c #f6eef6",
".N c #f6f2f6",
".w c #f6f6f6",
"#a c #fff6ff",
".G c #fffaff",
"Qt c #ffffff",
"QtQtQtQtQtQt.#.a.b.c.d.eQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.f.g.h.i.j.k.l.mQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQt.n.o.p.j.q.r.d.c.s.mQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.t.uQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQt.f.v.wQt.x.y.z.q.A.B.C.mQtQtQtQtQtQtQtQt.D.E.u.E.DQtQtQtQtQtQtQtQtQtQt.E.DQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQt.f.F.G.G.#.f.H.I.d.J.J.K.L.eQtQtQtQtQtQt.t.uQtQtQtQtQtQtQtQtQtQtQtQtQtQt.t.uQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"Qt.M.j.r.#.N.m.m.O.P.Q.N.e.z.R.S.eQtQtQtQtQt.E.uQtQtQtQtQtQtQt.u.E.D.EQtQtQt.E.uQtQt.E.uQtQt.E.uQtQtQt.u.E.D.EQtQt",
".m.z.F.j.z.p.f.T.U.q.G.#.V.p.a.I.I.WQtQtQtQt.t.u.t.u.tQtQtQtQtQtQtQt.t.uQtQt.t.uQtQt.t.uQtQt.t.uQtQtQtQtQtQt.t.uQt",
".X.Y.g.L.Z.0.v.Z.g.G.N.#.i.e.1.2.z.IQtQtQtQtQt.D.E.u.E.DQtQtQt.D.E.u.E.DQtQt.E.DQtQtQt.D.E.u.EQtQtQtQt.D.E.u.E.DQt",
".3.4.d.R.l.5.4.6.G.w.N.f.n.p.f.r.7.iQtQtQtQtQtQtQtQt.t.uQtQt.t.uQtQt.t.uQtQt.t.uQtQtQt.u.t.u.tQtQtQt.t.uQtQt.t.uQt",
"Qt.8.c.9#.##.g.w.G#a.M#b.m.n.2#c.#QtQtQtQtQtQtQtQtQt.E.uQtQt.E.uQtQt.E.uQtQt.E.uQtQtQtQt.E.DQtQtQtQt.E.uQtQt.E.uQt",
"QtQt.8.A.y.Z.nQt.G#d.N.f#b#e#f#g.GQtQtQtQtQt.t.u.t.u.tQtQtQtQt.u.t.u.t.uQtQt.t.uQtQtQtQt.t.uQtQtQtQtQt.u.t.u.t.uQt",
"QtQtQt#h.y#i.g.NQt.w.V.N.W.I#j#k#lQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQt.w.H#..l.v#aQtQt.p#m#n#o#p.WQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt#h.K.b.OQt#q.J#r#s#t#u.1QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQt.x.P#h.x.J.n#v#w#x#y#zQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQt.x#A#B.fQt.V.V.##d.GQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQt.h.eQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};

static const char* const img15_search[] = { 
"84 27 192 2",
".C c #10baff",
".q c #18baff",
".j c #29beff",
".r c #29c2ff",
".i c #31beff",
"#i c #31c6ff",
"#z c #39beff",
"#s c #39c2ff",
".k c #39c6ff",
"#0 c #41444a",
"#h c #41bef6",
".D c #41c6ff",
"#t c #41caff",
"ak c #4a4852",
"ad c #4a4c52",
"#L c #4a505a",
".P c #4acaff",
"aj c #52505a",
"#E c #52c2ff",
"#P c #52caff",
".s c #52ceff",
"#H c #5a5962",
"#M c #5a5d5a",
"#B c #5a5d62",
"#R c #5a5d6a",
".l c #5ac6f6",
".x c #5aceff",
"#N c #625d62",
"#v c #62616a",
"#n c #62656a",
".B c #62caff",
".w c #62d2ff",
"al c #6a6973",
"a6 c #6a6d7b",
".t c #6ad6ff",
"#K c #73bee6",
".y c #73caf6",
".h c #73ceff",
".v c #73d6ff",
"#5 c #7b7583",
"#V c #7b7d83",
"#a c #7b7d8b",
"#U c #7bbade",
".O c #7bc6ee",
".7 c #7bcaf6",
".p c #7bd2ff",
".E c #7bd6ff",
".u c #7bdaff",
"#Y c #83c6ee",
".I c #83d6ff",
".8 c #83daff",
"#j c #83deff",
"#4 c #8b8d94",
"#1 c #8b8d9c",
"a# c #8b95ac",
".F c #8bdeff",
".Q c #8be2ff",
"az c #948d8b",
"aU c #948d94",
"a9 c #949194",
"#Z c #94919c",
"aZ c #9495ac",
".T c #9499a4",
"#3 c #94bed5",
".G c #94deff",
".R c #94e2ff",
"a0 c #9c9dac",
"#2 c #9ca1b4",
".J c #9cb2c5",
".2 c #9cbecd",
".m c #9ccee6",
".S c #9cdaf6",
".H c #9ce2ff",
"a3 c #a47531",
"aT c #a4754a",
"a4 c #a4815a",
"aO c #a4a1ac",
"a5 c #a4a1bd",
"a. c #a4a5ac",
"#6 c #a4aabd",
"#O c #a4b2cd",
".z c #a4becd",
".0 c #a4e6ff",
"aV c #ac7931",
".3 c #acaab4",
"ae c #acaebd",
"#X c #acb2c5",
"aa c #accade",
".1 c #ace6ff",
".9 c #aceaff",
"aP c #b47d31",
"aK c #b48d62",
"aF c #b4aeb4",
"ac c #b4b2b4",
"#d c #b4b6bd",
"#x c #b4b6c5",
"#w c #b4bac5",
"aL c #bd8931",
"aE c #bd9162",
"aY c #bd9573",
"a2 c #bdb6bd",
"#r c #bdbac5",
"#I c #bdbacd",
"#C c #bdbebd",
"aN c #bdbec5",
"#k c #bdeeff",
"aJ c #c58931",
"ay c #c59962",
"#p c #c5bec5",
"#c c #c5c2c5",
".U c #c5c2cd",
"#o c #c5c6d5",
"ai c #c5cad5",
".g c #c5e2f6",
"## c #c5e6ff",
"#. c #c5eeff",
"aG c #cd9131",
"aA c #cd9531",
"#Q c #cdcacd",
"#S c #cdcad5",
"#y c #cdcade",
".6 c #cdcede",
".n c #cdd2de",
".Z c #cddaee",
"#l c #cdeeff",
"#F c #cdf2ff",
"af c #d5a56a",
"an c #d5b28b",
"#D c #d5cecd",
"a8 c #d5ced5",
".V c #d5d2d5",
".M c #d5d6d5",
"#T c #d5d6de",
"#W c #d5d6e6",
"ab c #d5eaff",
".W c #ded6de",
"#b c #dedae6",
"as c #dedaee",
"#J c #deded5",
"a7 c #dedede",
"#e c #dedeee",
"#m c #def6ff",
"aS c #e6a131",
"ah c #e6be83",
"ar c #e6be94",
"am c #e6dade",
".K c #e6dee6",
".o c #e6e2e6",
".N c #e6e2ee",
"#7 c #e6e2f6",
"#g c #e6e6f6",
"at c #e6eaf6",
"#u c #e6f6ff",
"ag c #ee9110",
"aq c #ee9510",
"aD c #ee9910",
"aM c #ee9918",
"#8 c #eed2b4",
"aX c #eeda9c",
".A c #eee6ee",
"a1 c #eee6f6",
"#q c #eeeaee",
".c c #eeeaf6",
"#9 c #eeeaff",
".L c #eeeeee",
".b c #eeeef6",
".Y c #eeeeff",
"#f c #eef2ff",
"#A c #eefaff",
"ax c #f6b241",
"ap c #f6b641",
"ao c #f6c673",
".d c #f6eef6",
".e c #f6f2f6",
".a c #f6f2ff",
".5 c #f6f6f6",
".X c #f6f6ff",
".4 c #f6faff",
"#G c #f6ffff",
"au c #ffd673",
"aw c #ffda94",
"aR c #ffde94",
"aQ c #ffe68b",
"aB c #ffea8b",
"aH c #ffee8b",
"aW c #ffee94",
"aC c #fff6cd",
".f c #fff6ff",
"aI c #fffacd",
".# c #fffaff",
"av c #ffffcd",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQt.#.a.b.b.c.d.eQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQt.f.g.h.i.j.j.k.l.m.n.eQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.#.o.p.q.r.s.t.u.v.w.x.y.z.AQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.o.B.C.D.w.E.F.G.H.G.F.v.I.J.KQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"Qt.L.K.M.N.O.C.P.t.u.Q.R.H.H.H.R.R.G.S.T.U.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.W.V.M.V.V.W.L.#",
".X.Y.X.#.Z.q.k.t.u.R.G.H.G.R.F.F.G.0.1.2.3.Y.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.c.V.V.5",
".6.N.X.a.7.q.w.u.R.R.H.G.F.8.F.G.0.9#.###a#b.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.X.4.X.#.XQt.X#c.L",
"#d#e#f#g#h#i.t.F.G.R.F.F.u#j.F.0.1#k#l#m#n#o.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X.XQt#p#q",
"#r#e.X#b#s#t.u.F.H.F#j.u#j.G.0.1#.#l#m#u#v#w.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.#.##c.A",
"#x#e#f#y#z.P.8.R.F#j.u#j.F.0.1#k#.#m#m#A#B#x#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.X.##C#q",
"#r#e.X#D#E#t.F.G.F.u#j.G.0.1#.#F#m#u#G#G#H#I.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.#.##c.A",
"#d#e.a#J#K.P.u.R.8#j.F.0.1#k#.#m#m#A.4.##L#o.a.X#f.X.a.X#f.X.a.X#f.X#M#N#M#N.a.X#f#N#M#N#M#N.a.X#M#N#M#N#M.X.a.X#f#N#M#N#M.X.a.X#f.X#M#N#M.X.a.X#f.X.a.X#f.X.a.X.X.##p#q",
"#r#e.X.b#O#P.v.F.F.G.0.9#.#F#m#u#G#GQt#Q#R#S.X.X.X.X.X.X.X.X.X.X.X#M#N.X.X.X#N.X.X#M#N.X.X.X.X.X#N#M.X.X#N#M.X.X#N#M.X.X.X#M.X.X.X.X#N#M#N.X.X.X.X.X.X.X.X.X.X.X.#.##c.A",
"#x#e#f.X#T#U.t#j.G.0.1#k#.#m#m#A.4Qt.##v#V#W#f.X.a.X#f.X.a.X#f.X.a#N#M.X.a.X#f.X.a#N#M.X.a.X#f.X#M#N#f.X#M#N#f.X#M#N#f.X.a.X#f.X.a#N#M.X#M#N#f.X.a.X#f.X.a.X#f.X.X.##C#q",
"#r#e.X.X.X#X#Y.G.0.9#.#F#m#u#G#GQtQt#Z#0#1#g.X.X.X.X.X.X.X.X.X.X.X#M#N.X.X.X.X.X.X#M#N#M#N#M.X.X#N#M#N#M#N.X.X.X#N#M.X.X.X.X.X.X.X#M#N.X#N#M.X.X.X.X.X.X.X.X.X.X.#.##c.A",
"#d#e.a.X#f.Y#2#3.1#k#l#m#m#A.4Qt.5#4#0#5#6#7#8.a#f.X.a.X#f.X.a.X#f#N#M.X#f.X.a.X#f#N#M.X#f.X.a.X#M#N#M#N#f.X.a.X#M#N.a.X#f.X.a.X#M#N#M#N#M#N#M.X#f.X.a.X#f.X.a.X.X.##p#q",
"#r#e.X.X.X.a#9a.a#aaab#u#G.4.cac#vad#aae#yafagah.X.X.X.X.X.X.X.X.X#M#N.X.X.X#N.X.X#M#N.X.X.X.X.X#N#M.X#M#N.X.X.X#N#M.X.X.X#M.X.X#N#M.X.X.X#M#N.X.X.X.X.X.X.X.X.X.#.##c.A",
"#x#e#f.X.a.X#f#9ai#Z#najakajajal#4#w#Wamanaoapaqar.a#f.X.a.X#f.X.a.X#M#N#M#N#f.X.a#N#M#N#M#N#f.X#M#N#f.X#M#N#f.X.a#N#M#N#M.X#f.X#M#N#f.X.a#N#M.X.a.X#f.X.a.X#f.X.X.##C#q",
"#r#e.X.X.X.X.X.X.a#g#W#o.U.U#y.6asat.Xanauavawaxaqay#9.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.#.##c.A",
"#d#e.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X#9azaAaBaCawaxaDaE#9#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X.X.##p#q",
"#r#e.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XaFaGaHaIawaxaDaE.Y.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.#.##c.A",
"#x#e#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.aaFaJaBaCawaxaqaK.Y#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.a.X#f.X.X.##C#q",
"#r#W.a.a.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XaFaLaBaIawapaMaK#9.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.#.##c#q",
"aN.U#b#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#gaOaPaQaIaRaSaT#w#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#g#9.X.X.V.e",
".d.U#o#o#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#SaiaUaVaWaXaYaZa0ai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#Sai#yai#y.6a1#q#q.#",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQta2a3a4a5a6a7QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.#Qt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQta8a9aU#QQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};


/*
 *  Constructs a search as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
search::search( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ),
      image0( (const char **) img0_search ),
      image1( (const char **) img1_search ),
      image2( (const char **) img2_search ),
      image3( (const char **) img3_search ),
      image4( (const char **) img4_search ),
      image5( (const char **) img5_search ),
      image6( (const char **) img6_search ),
      image7( (const char **) img7_search ),
      image8( (const char **) img8_search ),
      image9( (const char **) img9_search ),
      image10( (const char **) img10_search ),
      image11( (const char **) img11_search ),
      image12( (const char **) img12_search ),
      image13( (const char **) img13_search ),
      image14( (const char **) img14_search ),
      image15( (const char **) img15_search )
{
    if ( !name )
	setName( "search" );
    setMinimumSize( QSize( 50, 450 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    searchLayout = new QGridLayout( this, 1, 1, 0, 0, "searchLayout"); 

    layout59 = new QHBoxLayout( 0, 0, 0, "layout59"); 
    spacer43 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout59->addItem( spacer43 );

    layout78_2 = new QHBoxLayout( 0, 0, 0, "layout78_2"); 

    pixmapLabel1_2_3 = new QLabel( this, "pixmapLabel1_2_3" );
    pixmapLabel1_2_3->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_3->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_3->setPixmap( image0 );
    pixmapLabel1_2_3->setScaledContents( FALSE );
    layout78_2->addWidget( pixmapLabel1_2_3 );

    frame58_2 = new QFrame( this, "frame58_2" );
    frame58_2->setMinimumSize( QSize( 50, 23 ) );
    frame58_2->setMaximumSize( QSize( 32767, 23 ) );
    frame58_2->setPaletteBackgroundPixmap( image1 );
    frame58_2->setFrameShape( QFrame::NoFrame );
    frame58_2->setFrameShadow( QFrame::Plain );
    layout78_2->addWidget( frame58_2 );

    pixmapLabel1_2_2_2 = new QLabel( this, "pixmapLabel1_2_2_2" );
    pixmapLabel1_2_2_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2_2->setPixmap( image2 );
    pixmapLabel1_2_2_2->setScaledContents( FALSE );
    layout78_2->addWidget( pixmapLabel1_2_2_2 );
    layout59->addLayout( layout78_2 );
    spacer46_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout59->addItem( spacer46_2 );

    searchLayout->addMultiCellLayout( layout59, 2, 2, 0, 2 );
    spacer140 = new QSpacerItem( 20, 15, QSizePolicy::Minimum, QSizePolicy::Fixed );
    searchLayout->addItem( spacer140, 1, 1 );

    layout119 = new QVBoxLayout( 0, 0, 0, "layout119"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 50, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image3 );
    layout119->addWidget( textLabel1 );

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 50, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image4 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    pixmapLabel1 = new QLabel( frame16, "pixmapLabel1" );
    pixmapLabel1->setMinimumSize( QSize( 166, 21 ) );
    pixmapLabel1->setMaximumSize( QSize( 166, 21 ) );
    pixmapLabel1->setPixmap( image5 );
    pixmapLabel1->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel1, 0, 0 );

    pixmapLabel2_2 = new QLabel( frame16, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setPixmap( image6 );
    pixmapLabel2_2->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel2_2, 0, 2 );
    spacer212 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer212, 0, 1 );
    layout119->addWidget( frame16 );

    searchLayout->addMultiCellLayout( layout119, 0, 0, 0, 2 );
    spacer43_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    searchLayout->addItem( spacer43_2, 3, 0 );
    spacer46_2_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    searchLayout->addItem( spacer46_2_2, 3, 2 );

    layout61 = new QHBoxLayout( 0, 0, 0, "layout61"); 
    spacer43_3 = new QSpacerItem( 16, 12, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout61->addItem( spacer43_3 );

    layout41_2 = new QHBoxLayout( 0, 0, 0, "layout41_2"); 

    pixmapLabel3_3 = new QLabel( this, "pixmapLabel3_3" );
    pixmapLabel3_3->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel3_3->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel3_3->setPixmap( image7 );
    pixmapLabel3_3->setScaledContents( FALSE );
    layout41_2->addWidget( pixmapLabel3_3 );

    pixmapLabel3_2_2_2 = new QLabel( this, "pixmapLabel3_2_2_2" );
    pixmapLabel3_2_2_2->setMinimumSize( QSize( 50, 18 ) );
    pixmapLabel3_2_2_2->setMaximumSize( QSize( 32767, 18 ) );
    pixmapLabel3_2_2_2->setPaletteBackgroundPixmap( image8 );
    pixmapLabel3_2_2_2->setLineWidth( 0 );
    pixmapLabel3_2_2_2->setScaledContents( FALSE );
    layout41_2->addWidget( pixmapLabel3_2_2_2 );

    pixmapLabel3_2_3 = new QLabel( this, "pixmapLabel3_2_3" );
    pixmapLabel3_2_3->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel3_2_3->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel3_2_3->setLineWidth( 0 );
    pixmapLabel3_2_3->setPixmap( image9 );
    pixmapLabel3_2_3->setScaledContents( FALSE );
    layout41_2->addWidget( pixmapLabel3_2_3 );
    layout61->addLayout( layout41_2 );
    spacer46_2_3 = new QSpacerItem( 16, 12, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout61->addItem( spacer46_2_3 );

    searchLayout->addMultiCellLayout( layout61, 4, 4, 0, 2 );

    layout23 = new QHBoxLayout( 0, 0, 0, "layout23"); 

    frame15 = new QFrame( this, "frame15" );
    frame15->setMinimumSize( QSize( 50, 31 ) );
    frame15->setMaximumSize( QSize( 32767, 31 ) );
    frame15->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame15->setPaletteBackgroundPixmap( image10 );
    frame15->setFrameShape( QFrame::NoFrame );
    frame15->setFrameShadow( QFrame::Plain );
    frame15->setLineWidth( 0 );
    frame15Layout = new QGridLayout( frame15, 1, 1, 0, 0, "frame15Layout"); 
    spacer38 = new QSpacerItem( 40, 18, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame15Layout->addItem( spacer38, 0, 0 );

    layout22 = new QVBoxLayout( 0, 0, 0, "layout22"); 
    spacer37 = new QSpacerItem( 20, 15, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout22->addItem( spacer37 );

    exitButtonPlaceHolder = new QLabel( frame15, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setPixmap( image11 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    layout22->addWidget( exitButtonPlaceHolder );

    frame15Layout->addLayout( layout22, 0, 1 );
    layout23->addWidget( frame15 );

    aboutButtonPlaceHolder = new QLabel( this, "aboutButtonPlaceHolder" );
    aboutButtonPlaceHolder->setMinimumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setMaximumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setLineWidth( 0 );
    aboutButtonPlaceHolder->setPixmap( image12 );
    aboutButtonPlaceHolder->setScaledContents( FALSE );
    layout23->addWidget( aboutButtonPlaceHolder );

    searchLayout->addMultiCellLayout( layout23, 5, 5, 0, 2 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 140, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image13 );
    pixmapLabel9_2->setScaledContents( FALSE );

    searchLayout->addMultiCellWidget( pixmapLabel9_2, 6, 6, 0, 2 );

    frame20 = new QFrame( this, "frame20" );
    frame20->setMinimumSize( QSize( 130, 0 ) );
    frame20->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 238, 239, 241) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    frame20->setPalette( pal );
    frame20->setFrameShape( QFrame::Box );
    frame20->setFrameShadow( QFrame::Plain );
    frame20->setMargin( 0 );
    frame20Layout = new QGridLayout( frame20, 1, 1, 0, 0, "frame20Layout"); 

    layout59_2 = new QVBoxLayout( 0, 0, 0, "layout59_2"); 
    spacer33 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout59_2->addItem( spacer33 );

    layout75 = new QHBoxLayout( 0, 0, 0, "layout75"); 

    layout64 = new QHBoxLayout( 0, 0, 0, "layout64"); 

    layout33 = new QHBoxLayout( 0, 0, 0, "layout33"); 
    spacer31 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout33->addItem( spacer31 );

    frame7 = new QFrame( frame20, "frame7" );
    frame7->setFrameShape( QFrame::NoFrame );
    frame7->setFrameShadow( QFrame::Plain );
    frame7->setLineWidth( 0 );
    frame7Layout = new QGridLayout( frame7, 1, 1, 0, 0, "frame7Layout"); 

    layout41 = new QHBoxLayout( 0, 0, 0, "layout41"); 

    pixmapLabel3 = new QLabel( frame7, "pixmapLabel3" );
    pixmapLabel3->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel3->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel3->setPixmap( image7 );
    pixmapLabel3->setScaledContents( FALSE );
    layout41->addWidget( pixmapLabel3 );

    pixmapLabel3_2_2 = new QLabel( frame7, "pixmapLabel3_2_2" );
    pixmapLabel3_2_2->setMinimumSize( QSize( 152, 18 ) );
    pixmapLabel3_2_2->setMaximumSize( QSize( 32767, 18 ) );
    pixmapLabel3_2_2->setPaletteBackgroundPixmap( image8 );
    pixmapLabel3_2_2->setLineWidth( 0 );
    pixmapLabel3_2_2->setScaledContents( FALSE );
    layout41->addWidget( pixmapLabel3_2_2 );

    pixmapLabel3_2 = new QLabel( frame7, "pixmapLabel3_2" );
    pixmapLabel3_2->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel3_2->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel3_2->setLineWidth( 0 );
    pixmapLabel3_2->setPixmap( image9 );
    pixmapLabel3_2->setScaledContents( FALSE );
    layout41->addWidget( pixmapLabel3_2 );

    frame7Layout->addLayout( layout41, 2, 0 );

    layout78 = new QHBoxLayout( 0, 0, 0, "layout78"); 

    pixmapLabel1_2 = new QLabel( frame7, "pixmapLabel1_2" );
    pixmapLabel1_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2->setPixmap( image0 );
    pixmapLabel1_2->setScaledContents( FALSE );
    layout78->addWidget( pixmapLabel1_2 );

    frame58 = new QFrame( frame7, "frame58" );
    frame58->setMinimumSize( QSize( 130, 23 ) );
    frame58->setMaximumSize( QSize( 32767, 23 ) );
    frame58->setPaletteBackgroundPixmap( image1 );
    frame58->setFrameShape( QFrame::NoFrame );
    frame58->setFrameShadow( QFrame::Plain );

    foundUsers = new QLabel( frame58, "foundUsers" );
    foundUsers->setGeometry( QRect( 0, 4, 150, 18 ) );
    foundUsers->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    foundUsers->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont foundUsers_font(  foundUsers->font() );
    foundUsers_font.setBold( TRUE );
    foundUsers->setFont( foundUsers_font ); 
    layout78->addWidget( frame58 );

    pixmapLabel1_2_2 = new QLabel( frame7, "pixmapLabel1_2_2" );
    pixmapLabel1_2_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2->setPixmap( image2 );
    pixmapLabel1_2_2->setScaledContents( FALSE );
    layout78->addWidget( pixmapLabel1_2_2 );

    frame7Layout->addLayout( layout78, 0, 0 );

    onlinePeople = new QListView( frame7, "onlinePeople" );
    onlinePeople->addColumn( ( "Column 1" ) );
    onlinePeople->addColumn( ( "Column2" ) );
    onlinePeople->header()->setClickEnabled( FALSE, onlinePeople->header()->count() - 1 );
    onlinePeople->header()->setResizeEnabled( FALSE, onlinePeople->header()->count() - 1 );
    onlinePeople->setFrameShape( QListView::Box );
    onlinePeople->setFrameShadow( QListView::Plain );
    onlinePeople->setLineWidth( 1 );
    onlinePeople->setVScrollBarMode( QListView::AlwaysOn );
    onlinePeople->setDragAutoScroll( TRUE );
    onlinePeople->setSelectionMode( QListView::Single );
    onlinePeople->setAllColumnsShowFocus( TRUE );

    frame7Layout->addWidget( onlinePeople, 1, 0 );
    layout33->addWidget( frame7 );
    layout64->addLayout( layout33 );
    layout75->addLayout( layout64 );
    spacer78 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout75->addItem( spacer78 );
    layout59_2->addLayout( layout75 );
    spacer77 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout59_2->addItem( spacer77 );

    frame20Layout->addLayout( layout59_2, 0, 0 );

    layout60 = new QVBoxLayout( 0, 0, 0, "layout60"); 
    spacer93 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout60->addItem( spacer93 );

    layout56 = new QHBoxLayout( 0, 0, 0, "layout56"); 
    spacer90 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout56->addItem( spacer90 );

    frame24 = new QFrame( frame20, "frame24" );
    frame24->setFrameShape( QFrame::StyledPanel );
    frame24->setFrameShadow( QFrame::Raised );
    frame24->setLineWidth( 0 );
    frame24Layout = new QGridLayout( frame24, 1, 1, 0, 0, "frame24Layout"); 

    layout53 = new QHBoxLayout( 0, 0, 0, "layout53"); 

    layout69 = new QHBoxLayout( 0, 0, 0, "layout69"); 

    layout33_5 = new QVBoxLayout( 0, 0, 0, "layout33_5"); 

    label0 = new QLabel( frame24, "label0" );
    label0->setMinimumSize( QSize( 130, 20 ) );
    label0->setMaximumSize( QSize( 150, 20 ) );
    label0->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont label0_font(  label0->font() );
    label0_font.setBold( TRUE );
    label0->setFont( label0_font ); 
    layout33_5->addWidget( label0 );

    combo0 = new QComboBox( FALSE, frame24, "combo0" );
    combo0->setMinimumSize( QSize( 120, 20 ) );
    combo0->setMaximumSize( QSize( 120, 20 ) );
    combo0->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    combo0->setPalette( pal );
    combo0->setBackgroundOrigin( QComboBox::AncestorOrigin );
    combo0->setFocusPolicy( QComboBox::ClickFocus );
    layout33_5->addWidget( combo0 );
    layout69->addLayout( layout33_5 );
    layout53->addLayout( layout69 );
    spacer133 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout53->addItem( spacer133 );

    layout48 = new QVBoxLayout( 0, 0, 0, "layout48"); 

    label1 = new QLabel( frame24, "label1" );
    label1->setMinimumSize( QSize( 130, 20 ) );
    label1->setMaximumSize( QSize( 150, 20 ) );
    label1->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont label1_font(  label1->font() );
    label1_font.setBold( TRUE );
    label1->setFont( label1_font ); 
    layout48->addWidget( label1 );

    combo1 = new QComboBox( FALSE, frame24, "combo1" );
    combo1->setMinimumSize( QSize( 120, 20 ) );
    combo1->setMaximumSize( QSize( 120, 20 ) );
    combo1->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    combo1->setPalette( pal );
    combo1->setBackgroundOrigin( QComboBox::AncestorOrigin );
    combo1->setFocusPolicy( QComboBox::ClickFocus );
    layout48->addWidget( combo1 );
    layout53->addLayout( layout48 );
    spacer37_2 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout53->addItem( spacer37_2 );

    layout50 = new QVBoxLayout( 0, 0, 0, "layout50"); 
    spacer38_2 = new QSpacerItem( 20, 17, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout50->addItem( spacer38_2 );

    layout49 = new QHBoxLayout( 0, 0, 0, "layout49"); 

    searchSave = new QComboBox( FALSE, frame24, "searchSave" );
    searchSave->setMinimumSize( QSize( 120, 20 ) );
    searchSave->setMaximumSize( QSize( 120, 20 ) );
    searchSave->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    searchSave->setPalette( pal );
    searchSave->setBackgroundOrigin( QComboBox::AncestorOrigin );
    searchSave->setFocusPolicy( QComboBox::ClickFocus );
    layout49->addWidget( searchSave );
    spacer43_4 = new QSpacerItem( 5, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout49->addItem( spacer43_4 );

    saveButtonPlaceHolder = new QLabel( frame24, "saveButtonPlaceHolder" );
    saveButtonPlaceHolder->setMinimumSize( QSize( 57, 17 ) );
    saveButtonPlaceHolder->setMaximumSize( QSize( 57, 17 ) );
    saveButtonPlaceHolder->setPixmap( image14 );
    saveButtonPlaceHolder->setScaledContents( FALSE );
    layout49->addWidget( saveButtonPlaceHolder );
    layout50->addLayout( layout49 );
    layout53->addLayout( layout50 );
    spacer135 = new QSpacerItem( 95, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout53->addItem( spacer135 );

    frame24Layout->addLayout( layout53, 0, 0 );

    layout54 = new QHBoxLayout( 0, 0, 0, "layout54"); 

    layout71 = new QHBoxLayout( 0, 0, 0, "layout71"); 

    layout33_3 = new QVBoxLayout( 0, 0, 0, "layout33_3"); 

    label2 = new QLabel( frame24, "label2" );
    label2->setMinimumSize( QSize( 130, 20 ) );
    label2->setMaximumSize( QSize( 150, 20 ) );
    label2->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont label2_font(  label2->font() );
    label2_font.setBold( TRUE );
    label2->setFont( label2_font ); 
    layout33_3->addWidget( label2 );

    combo2 = new QComboBox( FALSE, frame24, "combo2" );
    combo2->setMinimumSize( QSize( 120, 20 ) );
    combo2->setMaximumSize( QSize( 120, 20 ) );
    combo2->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    combo2->setPalette( pal );
    combo2->setBackgroundOrigin( QComboBox::AncestorOrigin );
    combo2->setFocusPolicy( QComboBox::ClickFocus );
    layout33_3->addWidget( combo2 );
    layout71->addLayout( layout33_3 );
    layout54->addLayout( layout71 );
    spacer134 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout54->addItem( spacer134 );

    layout72 = new QHBoxLayout( 0, 0, 0, "layout72"); 

    layout33_4 = new QVBoxLayout( 0, 0, 0, "layout33_4"); 

    label3 = new QLabel( frame24, "label3" );
    label3->setMinimumSize( QSize( 130, 20 ) );
    label3->setMaximumSize( QSize( 150, 20 ) );
    label3->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont label3_font(  label3->font() );
    label3_font.setBold( TRUE );
    label3->setFont( label3_font ); 
    layout33_4->addWidget( label3 );

    combo3 = new QComboBox( FALSE, frame24, "combo3" );
    combo3->setMinimumSize( QSize( 120, 20 ) );
    combo3->setMaximumSize( QSize( 120, 20 ) );
    combo3->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    combo3->setPalette( pal );
    combo3->setBackgroundOrigin( QComboBox::AncestorOrigin );
    combo3->setFocusPolicy( QComboBox::ClickFocus );
    layout33_4->addWidget( combo3 );
    layout72->addLayout( layout33_4 );
    layout54->addLayout( layout72 );
    spacer136 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout54->addItem( spacer136 );

    layout33_4_2 = new QVBoxLayout( 0, 0, 0, "layout33_4_2"); 

    label4 = new QLabel( frame24, "label4" );
    label4->setMinimumSize( QSize( 130, 20 ) );
    label4->setMaximumSize( QSize( 150, 20 ) );
    label4->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    QFont label4_font(  label4->font() );
    label4_font.setBold( TRUE );
    label4->setFont( label4_font ); 
    layout33_4_2->addWidget( label4 );

    combo4 = new QComboBox( FALSE, frame24, "combo4" );
    combo4->setMinimumSize( QSize( 120, 20 ) );
    combo4->setMaximumSize( QSize( 120, 20 ) );
    combo4->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    combo4->setPalette( pal );
    combo4->setBackgroundOrigin( QComboBox::AncestorOrigin );
    combo4->setFocusPolicy( QComboBox::ClickFocus );
    layout33_4_2->addWidget( combo4 );
    layout54->addLayout( layout33_4_2 );
    spacer39 = new QSpacerItem( 19, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout54->addItem( spacer39 );

    layout120 = new QVBoxLayout( 0, 0, 0, "layout120"); 
    spacer137 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout120->addItem( spacer137 );

    searchButtonPlaceHolder = new QLabel( frame24, "searchButtonPlaceHolder" );
    searchButtonPlaceHolder->setMinimumSize( QSize( 84, 27 ) );
    searchButtonPlaceHolder->setMaximumSize( QSize( 84, 27 ) );
    searchButtonPlaceHolder->setPixmap( image15 );
    searchButtonPlaceHolder->setScaledContents( FALSE );
    layout120->addWidget( searchButtonPlaceHolder );
    layout54->addLayout( layout120 );
    spacer40 = new QSpacerItem( 57, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout54->addItem( spacer40 );

    frame24Layout->addLayout( layout54, 1, 0 );
    layout56->addWidget( frame24 );
    spacer91 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout56->addItem( spacer91 );
    layout60->addLayout( layout56 );
    spacer41 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout60->addItem( spacer41 );

    frame20Layout->addLayout( layout60, 2, 0 );

    layout55 = new QHBoxLayout( 0, 0, 0, "layout55"); 
    spacer75 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout55->addItem( spacer75 );

    frame10 = new QFrame( frame20, "frame10" );
    frame10->setMinimumSize( QSize( 0, 80 ) );
    frame10->setMaximumSize( QSize( 32767, 80 ) );
    frame10->setPaletteBackgroundColor( QColor( 239, 243, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 238, 239, 241) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 243, 255) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 243, 255) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 239, 243, 255) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    frame10->setPalette( pal );
    frame10->setFrameShape( QFrame::Box );
    frame10->setFrameShadow( QFrame::Plain );
    frame10Layout = new QGridLayout( frame10, 1, 1, 0, 0, "frame10Layout"); 

    layout47 = new QHBoxLayout( 0, 0, 0, "layout47"); 
    spacer107 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout47->addItem( spacer107 );

    layout45 = new QVBoxLayout( 0, 0, 6, "layout45"); 

    profileSwitch = new QRadioButton( frame10, "profileSwitch" );
    profileSwitch->setMinimumSize( QSize( 140, 18 ) );
    profileSwitch->setMaximumSize( QSize( 140, 18 ) );
    profileSwitch->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    profileSwitch->setBackgroundOrigin( QRadioButton::WidgetOrigin );
    layout45->addWidget( profileSwitch );

    layout43 = new QHBoxLayout( 0, 0, 0, "layout43"); 

    emailSwitch = new QRadioButton( frame10, "emailSwitch" );
    emailSwitch->setMinimumSize( QSize( 145, 18 ) );
    emailSwitch->setMaximumSize( QSize( 145, 18 ) );
    emailSwitch->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    emailSwitch->setBackgroundOrigin( QRadioButton::AncestorOrigin );
    layout43->addWidget( emailSwitch );

    emailEdit = new QLineEdit( frame10, "emailEdit" );
    emailEdit->setEnabled( TRUE );
    emailEdit->setMinimumSize( QSize( 100, 20 ) );
    emailEdit->setMaximumSize( QSize( 32767, 20 ) );
    emailEdit->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    emailEdit->setBackgroundOrigin( QLineEdit::WidgetOrigin );
    emailEdit->setEdited( FALSE );
    layout43->addWidget( emailEdit );
    layout45->addLayout( layout43 );

    layout44 = new QHBoxLayout( 0, 0, 0, "layout44"); 

    nickSwitch = new QRadioButton( frame10, "nickSwitch" );
    nickSwitch->setMinimumSize( QSize( 145, 18 ) );
    nickSwitch->setMaximumSize( QSize( 145, 18 ) );
    nickSwitch->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    nickSwitch->setBackgroundOrigin( QRadioButton::WidgetOrigin );
    layout44->addWidget( nickSwitch );

    nickEdit = new QLineEdit( frame10, "nickEdit" );
    nickEdit->setEnabled( TRUE );
    nickEdit->setMinimumSize( QSize( 100, 20 ) );
    nickEdit->setMaximumSize( QSize( 32767, 20 ) );
    nickEdit->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    nickEdit->setBackgroundOrigin( QLineEdit::WidgetOrigin );
    nickEdit->setEdited( FALSE );
    layout44->addWidget( nickEdit );
    layout45->addLayout( layout44 );
    layout47->addLayout( layout45 );
    spacer42 = new QSpacerItem( 45, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout47->addItem( spacer42 );

    layout46 = new QVBoxLayout( 0, 0, 6, "layout46"); 

    notInListFilter = new QCheckBox( frame10, "notInListFilter" );
    notInListFilter->setMinimumSize( QSize( 130, 0 ) );
    notInListFilter->setBackgroundOrigin( QCheckBox::WidgetOrigin );
    layout46->addWidget( notInListFilter );

    onlyAvailable = new QCheckBox( frame10, "onlyAvailable" );
    onlyAvailable->setMinimumSize( QSize( 140, 0 ) );
    layout46->addWidget( onlyAvailable );

    onlyPhoto = new QCheckBox( frame10, "onlyPhoto" );
    onlyPhoto->setMinimumSize( QSize( 130, 0 ) );
    layout46->addWidget( onlyPhoto );
    layout47->addLayout( layout46 );
    spacer140_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout47->addItem( spacer140_2 );

    frame10Layout->addLayout( layout47, 0, 0 );
    layout55->addWidget( frame10 );
    spacer76 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout55->addItem( spacer76 );

    frame20Layout->addLayout( layout55, 1, 0 );

    searchLayout->addWidget( frame20, 3, 1 );
    languageChange();
    resize( QSize(576, 491).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
search::~search()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void search::languageChange()
{
    setCaption( ( "OpenC6 - Ricerca contatti" ) );
    foundUsers->setText( ( "Utenti trovati" ) );
    onlinePeople->header()->setLabel( 0, ( "Column 1" ) );
    onlinePeople->header()->setLabel( 1, ( "Column2" ) );
    onlinePeople->clear();
    QListViewItem * item = new QListViewItem( onlinePeople, 0 );
    item->setText( 0, ( "New Item" ) );

    label0->setText( ( "textLabel1" ) );
    label1->setText( ( "textLabel1" ) );
    searchSave->clear();
    searchSave->insertItem( ( "--------------" ) );
    searchSave->insertItem( ( "Ricerca 1" ) );
    searchSave->insertItem( ( "Ricerca 2" ) );
    searchSave->insertItem( ( "Ricerca 3" ) );
    searchSave->insertItem( ( "Ricerca 4" ) );
    QToolTip::add( saveButtonPlaceHolder, ( "Salva nello slot selezionato i criteri correnti di ricerca" ) );
    label2->setText( ( "textLabel1" ) );
    label3->setText( ( "textLabel1" ) );
    label4->setText( ( "textLabel1" ) );
    profileSwitch->setText( ( "Cerca per profilo" ) );
    emailSwitch->setText( ( "Cerca per email" ) );
    nickSwitch->setText( ( "Cerca per nick" ) );
    notInListFilter->setText( ( "Mostra solo non in lista" ) );
    QToolTip::add( notInListFilter, ( "Mostra solo i netfriend che non sono presenti nella lista" ) );
    onlyAvailable->setText( ( "Mostra solo disponibili" ) );
    QToolTip::add( onlyAvailable, ( "Mostra solo i netfriend che non sono presenti nella lista" ) );
    onlyPhoto->setText( ( "Mostra solo con foto" ) );
    QToolTip::add( onlyPhoto, ( "Mostra solo i netfriend che non sono presenti nella lista" ) );
}

#include "search.moc"
